import { render, screen } from '@testing-library/react'
import { userEvent } from '@testing-library/user-event'
import { DataloadSectionType, FluidType } from 'enums'
import { Dataload } from 'models'
import React from 'react'
import {
  baseDataLoad,
  baseMultiFluidDataLoad,
} from 'tests/__mocks__/chartData.mock'
import DataloadSectionValue from './DataloadSectionValue'

const mockToggleEstimationModal = jest.fn()

describe('DataloadSectionValue component', () => {
  it('should render correctly', () => {
    const { container } = render(
      <DataloadSectionValue
        dataload={baseDataLoad}
        fluidType={FluidType.ELECTRICITY}
        dataloadSectionType={DataloadSectionType.NO_COMPARE}
        toggleEstimationModal={mockToggleEstimationModal}
      />
    )
    expect(container).toMatchSnapshot()
  })

  describe('case SingleFluid', () => {
    it('should render with unit when value < 1000', () => {
      render(
        <DataloadSectionValue
          dataload={baseDataLoad}
          fluidType={FluidType.ELECTRICITY}
          dataloadSectionType={DataloadSectionType.NO_COMPARE}
          toggleEstimationModal={mockToggleEstimationModal}
        />
      )
      expect(screen.getByText('12,00')).toBeInTheDocument()
      expect(screen.getByText('FLUID.ELECTRICITY.UNIT')).toBeInTheDocument()
    })
    it('should render with mega unit when value >= 1000', () => {
      const mockDataLoad: Dataload = { ...baseDataLoad, value: 1000 }
      render(
        <DataloadSectionValue
          dataload={mockDataLoad}
          fluidType={FluidType.ELECTRICITY}
          dataloadSectionType={DataloadSectionType.NO_COMPARE}
          toggleEstimationModal={mockToggleEstimationModal}
        />
      )
      expect(screen.getByText('1,00')).toBeInTheDocument()
      expect(screen.getByText('FLUID.ELECTRICITY.MEGAUNIT')).toBeInTheDocument()
    })
  })

  describe('case Multifluid', () => {
    it('should render correctly when comparison', () => {
      render(
        <DataloadSectionValue
          dataload={baseMultiFluidDataLoad}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.RIGHT}
          toggleEstimationModal={mockToggleEstimationModal}
        />
      )
      expect(screen.getByText('12,00')).toBeInTheDocument()
      expect(screen.getByText('FLUID.MULTIFLUID.UNIT')).toBeInTheDocument()
    })
    it('should render correctly with a estimated link when no comparison', () => {
      render(
        <DataloadSectionValue
          dataload={baseMultiFluidDataLoad}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.NO_COMPARE}
          toggleEstimationModal={mockToggleEstimationModal}
        />
      )
      expect(screen.getByText('12,00')).toBeInTheDocument()
      expect(
        screen.getByText('consumption_visualizer.estimated')
      ).toBeInTheDocument()
    })
    it('should call toggleEstimationModal when click on the estimated link', async () => {
      render(
        <DataloadSectionValue
          dataload={baseMultiFluidDataLoad}
          fluidType={FluidType.MULTIFLUID}
          dataloadSectionType={DataloadSectionType.NO_COMPARE}
          toggleEstimationModal={mockToggleEstimationModal}
        />
      )
      await userEvent.click(
        screen.getByText('consumption_visualizer.estimated')
      )
      expect(mockToggleEstimationModal).toHaveBeenCalled()
    })
  })
})
